==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=bs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'iskljucivo za sljedece  clanke (bez uticaja na bazupodataka).',
	'bouton_radio_articles_tous' => 'bez iznimke za sve clanke.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'za sve clanke osim onih ciji forum je dezaktiviran.',
	'bouton_radio_enregistrement_obligatoire' => 'Obavezno registrovanje (korisnici trebaju upisati svoju e-mail adresu prije mogucnosti postavljanja svojih prijedloga).',
	'bouton_radio_moderation_priori' => 'Pre-moderation (prijedlozi se ne prikazuju na javnoj stranici prije ovjere od strane administratora).', # MODIF
	'bouton_radio_modere_abonnement' => 'registracija obavezna',
	'bouton_radio_modere_posteriori' => 'post-moderation', # MODIF
	'bouton_radio_modere_priori' => 'pre-moderation', # MODIF
	'bouton_radio_publication_immediate' => 'Direktna publikacija poruka (prijedlozi se prikazuju nakon slanja, administratori ih  odmah mogu izbrisati).',

	// F
	'form_pet_message_commentaire' => 'Da li zelite napisati poruku ili komentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nemate vise pristup ovim forumima.',
	'forum_attention_dix_caracteres' => '<b>Upozorenje!</b> Vasa poruka mora sadrzati najmanje deset karaktera.',
	'forum_attention_trois_caracteres' => '<b>Upozorenje!</b> Vaš naslov mora imati najmanje tri karaktera.',
	'forum_avez_selectionne' => 'Izabrali ste:',
	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>ici</a> da bi ste nastavili.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Ovaj forum je vlasnistvo urednika: vas prijedlog ce biti postavljen tek nakon sto je ovjeren od strane administratora.', # MODIF
	'forum_lien_hyper' => '<b>Hipertekstualni link</b> (optionnel)', # MODIF
	'forum_message_definitif' => 'Definitivna poruka: posalji na stranicu',
	'forum_message_trop_long' => 'Vasa poruka je preduga. Maksimalna velicina je 20000 karaktera.', # MODIF
	'forum_ne_repondez_pas' => 'Ne odgovarajte na ovu poruku osim u forumu na sljedecu adresu:', # MODIF
	'forum_page_url' => '(Ako se vasa poruka odnosi na clanak objavljen na web-u, ili na stranicu koja pruza dodatne informacije, mozete na kraju naznaciti naziv i URL adresu stranice.)',
	'forum_poste_par' => 'Poruku postavio/la@parauteur@; poruka slijedi nakon vaseg clanka.', # MODIF
	'forum_qui_etes_vous' => '<b>Ko ste?</b> (optionnel)', # MODIF
	'forum_texte' => 'Tekst vase poruke:', # MODIF
	'forum_titre' => 'Tema:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Ptvrdite ovaj izbor',
	'forum_voir_avant' => 'Pogledaj poruku', # MODIF
	'forum_votre_email' => 'Vasa e-mail adresa:', # MODIF
	'forum_votre_nom' => 'Vase ime (ili pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Da bi ste ucestvovali u ovom forumu, morate se prijaviti. Naznacite ispod licni identifikator koji vam je dodjeljen. Ako niste vec registrovani, trebate',
	'forum_vous_inscrire' => 'se upisati.',

	// I
	'icone_poster_message' => 'Postavi poruku',
	'icone_suivi_forum' => 'Posmatranje javnog foruma: @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'Prati/uredi foruma',
	'icone_supprimer_message' => 'Izbrisi ovu poruku',
	'icone_valider_message' => 'Ovjeri ovu poruku',
	'info_activer_forum_public' => '<i>Da bi ste aktivirali javne forume, izaberite njihov standardni nacin moderacije</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Usvoji ovaj izbor moderacije:',
	'info_desactiver_forum_public' => 'Dezaktivirati koristenje javnih foruma. Javni forumi mogu dobiti individualnu autorizaciju za clanke; bice zabranjeni za rubrike, kratke  poruke, itd.',
	'info_envoi_forum' => 'Slanje foruma autorima clanaka',
	'info_fonctionnement_forum' => 'Funkcionisanje foruma:',
	'info_gauche_suivi_forum_2' => 'Strana <i>pracenja foruma</i> je alatka za rukovodjene vasom stranicom (ne prostor za  diskusiju i redakciju). Ona izlistava sve doprinose foruma ovog clanka, kako na privatnoj tako i na javnoj stranici, i dozvoljava rukovodjenje tim doprinosima.', # MODIF
	'info_liens_syndiques_3' => 'forumi',
	'info_liens_syndiques_4' => 'su',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'na cekanju za ovjeru',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardni nacin funkcionisanja javnih foruma',
	'info_option_email' => 'Kada posjetioc sranice postavi novu poruku u forum vezan za neki clanak, autori clanka mogu biti o tome upozoreni putem e-maila. Zelite li koristiti ovu opciju?', # MODIF
	'info_pas_de_forum' => 'nema foruma',
	'item_activer_forum_administrateur' => 'Aktiviraj forum administratora',
	'item_desactiver_forum_administrateur' => 'Dezaktiviraj forum za administratore',

	// L
	'lien_reponse_article' => 'Odgovori na clanak',
	'lien_reponse_breve_2' => 'Odgovori na kratku poruku',
	'lien_reponse_rubrique' => 'Odgovori na rubriku',
	'lien_reponse_site_reference' => 'Odgovori na referenciranu stranicu:', # MODIF

	// O
	'onglet_messages_internes' => 'Interne poruke',
	'onglet_messages_publics' => 'Javne poruke',
	'onglet_messages_vide' => 'Poruke bez teksta',

	// R
	'repondre_message' => 'Odgovori na ovu poruku',

	// T
	'titre_cadre_forum_administrateur' => 'Privatni forum za administratore',
	'titre_cadre_forum_interne' => 'Interni forum',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Pracenje foruma',
	'titre_page_forum_suivi' => 'Pracenje foruma',
];

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=bs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'iskljucivo za sljedece  clanke (bez uticaja na bazupodataka).',
	'bouton_radio_articles_tous' => 'bez iznimke za sve clanke.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'za sve clanke osim onih ciji forum je dezaktiviran.',
	'bouton_radio_enregistrement_obligatoire' => 'Obavezno registrovanje (korisnici trebaju upisati svoju e-mail adresu prije mogucnosti postavljanja svojih prijedloga).', # MODIF
	'bouton_radio_moderation_priori' => 'Pre-moderation (prijedlozi se ne prikazuju na javnoj stranici prije ovjere od strane administratora).', # MODIF
	'bouton_radio_modere_abonnement' => 'registracija obavezna',
	'bouton_radio_modere_posteriori' => 'post-moderation', # MODIF
	'bouton_radio_modere_priori' => 'pre-moderation', # MODIF
	'bouton_radio_publication_immediate' => 'Direktna publikacija poruka (prijedlozi se prikazuju nakon slanja, administratori ih  odmah mogu izbrisati).', # MODIF

	// F
	'form_pet_message_commentaire' => 'Da li zelite napisati poruku ili komentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nemate vise pristup ovim forumima.',
	'forum_attention_dix_caracteres' => '<b>Upozorenje!</b> Vasa poruka mora sadrzati najmanje deset karaktera.',
	'forum_attention_trois_caracteres' => '<b>Upozorenje!</b> Vaš naslov mora imati najmanje tri karaktera.',
	'forum_avez_selectionne' => 'Izabrali ste:',
	'forum_cliquer_retour' => 'Kliknite <a href=\'@retour_forum@\'>ici</a> da bi ste nastavili.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Ovaj forum je vlasnistvo urednika: vas prijedlog ce biti postavljen tek nakon sto je ovjeren od strane administratora.', # MODIF
	'forum_lien_hyper' => '<b>Hipertekstualni link</b> (optionnel)', # MODIF
	'forum_message_definitif' => 'Definitivna poruka: posalji na stranicu',
	'forum_message_trop_long' => 'Vasa poruka je preduga. Maksimalna velicina je 20000 karaktera.', # MODIF
	'forum_ne_repondez_pas' => 'Ne odgovarajte na ovu poruku osim u forumu na sljedecu adresu:', # MODIF
	'forum_page_url' => '(Ako se vasa poruka odnosi na clanak objavljen na web-u, ili na stranicu koja pruza dodatne informacije, mozete na kraju naznaciti naziv i URL adresu stranice.)',
	'forum_poste_par' => 'Poruku postavio/la@parauteur@; poruka slijedi nakon vaseg clanka.', # MODIF
	'forum_qui_etes_vous' => '<b>Ko ste?</b> (optionnel)', # MODIF
	'forum_texte' => 'Tekst vase poruke:', # MODIF
	'forum_titre' => 'Tema:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Ptvrdite ovaj izbor',
	'forum_voir_avant' => 'Pogledaj poruku', # MODIF
	'forum_votre_email' => 'Vasa e-mail adresa:', # MODIF
	'forum_votre_nom' => 'Vase ime (ili pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Da bi ste ucestvovali u ovom forumu, morate se prijaviti. Naznacite ispod licni identifikator koji vam je dodjeljen. Ako niste vec registrovani, trebate',
	'forum_vous_inscrire' => 'se upisati.',

	// I
	'icone_poster_message' => 'Postavi poruku',
	'icone_suivi_forum' => 'Posmatranje javnog foruma: @nb_forums@ contribution(s)',
	'icone_suivi_forums' => 'Prati/uredi foruma',
	'icone_supprimer_message' => 'Izbrisi ovu poruku',
	'icone_valider_message' => 'Ovjeri ovu poruku',
	'info_activer_forum_public' => '<i>Da bi ste aktivirali javne forume, izaberite njihov standardni nacin moderacije</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Usvoji ovaj izbor moderacije:',
	'info_desactiver_forum_public' => 'Dezaktivirati koristenje javnih foruma. Javni forumi mogu dobiti individualnu autorizaciju za clanke; bice zabranjeni za rubrike, kratke  poruke, itd.',
	'info_envoi_forum' => 'Slanje foruma autorima clanaka', # MODIF
	'info_fonctionnement_forum' => 'Funkcionisanje foruma:',
	'info_gauche_suivi_forum_2' => 'Strana <i>pracenja foruma</i> je alatka za rukovodjene vasom stranicom (ne prostor za  diskusiju i redakciju). Ona izlistava sve doprinose foruma ovog clanka, kako na privatnoj tako i na javnoj stranici, i dozvoljava rukovodjenje tim doprinosima.', # MODIF
	'info_liens_syndiques_3' => 'forumi',
	'info_liens_syndiques_4' => 'su',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'na cekanju za ovjeru',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardni nacin funkcionisanja javnih foruma',
	'info_option_email' => 'Kada posjetioc sranice postavi novu poruku u forum vezan za neki clanak, autori clanka mogu biti o tome upozoreni putem e-maila. Zelite li koristiti ovu opciju?', # MODIF
	'info_pas_de_forum' => 'nema foruma',
	'item_activer_forum_administrateur' => 'Aktiviraj forum administratora', # MODIF
	'item_desactiver_forum_administrateur' => 'Dezaktiviraj forum za administratore', # MODIF

	// L
	'lien_reponse_article' => 'Odgovori na clanak',
	'lien_reponse_breve_2' => 'Odgovori na kratku poruku',
	'lien_reponse_rubrique' => 'Odgovori na rubriku',
	'lien_reponse_site_reference' => 'Odgovori na referenciranu stranicu:', # MODIF

	// O
	'onglet_messages_internes' => 'Interne poruke',
	'onglet_messages_publics' => 'Javne poruke',
	'onglet_messages_vide' => 'Poruke bez teksta',

	// R
	'repondre_message' => 'Odgovori na ovu poruku',

	// T
	'titre_cadre_forum_administrateur' => 'Privatni forum za administratore', # MODIF
	'titre_cadre_forum_interne' => 'Interni forum',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Pracenje foruma',
	'titre_page_forum_suivi' => 'Pracenje foruma',
];
